==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Shape_regularization/navtreeindex0.js <==
var NAVTREEINDEX0 =
{
".html":[5,0],
".html":[5,0,0],
".html":[5,0,0,0],
".html":[5,0,0,1],
"Shape_regularization_2regularize_100_segments_angles_8cpp-example.html":[6,0],
"Shape_regularization_2regularize_100_segments_offsets_8cpp-example.html":[6,1],
"Shape_regularization_2regularize_15_segments_8cpp-example.html":[6,2],
"Shape_regularization_2regularize_closed_contour_8cpp-example.html":[6,3],
"Shape_regularization_2regularize_contour_8cpp-example.html":[6,4],
"Shape_regularization_2regularize_framework_8cpp-example.html":[6,5],
"Shape_regularization_2regularize_open_contour_8cpp-example.html":[6,6],
"Shape_regularization_2regularize_planes_8cpp-example.html":[6,7],
"Shape_regularization_2regularize_real_data_2_8cpp-example.html":[6,8],
"Shape_regularization_2regularize_simple_8cpp-example.html":[6,9],
"annotated.html":[5],
"citelist.html":[4],
"classCGAL_1_1Shape__regularization_1_1ContourDirections.html":[1,0,0,0],
"classCGAL_1_1Shape__regularization_1_1ContourDirections.html#a07f23b0d134d1dfb32158f485aab15b8":[1,0,0,0,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Longest__direction__2.html":[1,0,2,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Longest__direction__2.html#a0fc2c281b36b3f9c5824538734c485ff":[1,0,2,0,1],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Longest__direction__2.html#a3d35a4bb19800df5b7e46b6a5923b1f6":[1,0,2,0,2],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Longest__direction__2.html#ac341399a7d4ddc8941fa27fcc95cd130":[1,0,2,0,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Multiple__directions__2.html":[1,0,2,1],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Multiple__directions__2.html#a3bffe403cb918489cdde4362abbe0b2f":[1,0,2,1,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Multiple__directions__2.html#a8bc93ecb54966ddf4b5308f51e2b4f81":[1,0,2,1,1],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Multiple__directions__2.html#ab1775ab7c531dce022b9fa86dc95cde4":[1,0,2,1,2],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1User__defined__directions__2.html":[1,0,2,2],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1User__defined__directions__2.html#aa02be5c6aadc4a0c0699b3d8251bc0fc":[1,0,2,2,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1User__defined__directions__2.html#ac1ca61aba4d1ff79f9ef08e9fdac6425":[1,0,2,2,1],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1User__defined__directions__2.html#afe401731658a57d04a96397cbb7a8118":[1,0,2,2,2],
"classCGAL_1_1Shape__regularization_1_1NeighborQuery.html":[1,0,0,1],
"classCGAL_1_1Shape__regularization_1_1NeighborQuery.html#afe9ac86f81427f217a72ee74523e4ade":[1,0,0,1,0],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html":[1,0,8],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html#a14be6914a0f2c588e2dbb8d6aed68260":[1,0,8,2],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html#a90b302fd0cbbd391a432e1182bc9b362":[1,0,8,3],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html#ac0e7fc3b4fc8deb95693c64ce3b57e12":[1,0,8,1],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html#af40e65f2d3843f342d0beb237904bb21":[1,0,8,0],
"classCGAL_1_1Shape__regularization_1_1RegularizationType.html":[1,0,0,2],
"classCGAL_1_1Shape__regularization_1_1RegularizationType.html#a5fa1b89221a8d2515acff817ceeb6946":[1,0,0,2,2],
"classCGAL_1_1Shape__regularization_1_1RegularizationType.html#a6425688d6368960b0aa5bfd0e6e13541":[1,0,0,2,0],
"classCGAL_1_1Shape__regularization_1_1RegularizationType.html#ac5bd68e930f080c0b619b3541c5fad9c":[1,0,0,2,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html":[1,0,1,0],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a024a82b6ec049e436213c2d398a9f90c":[1,0,1,0,8],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a1e7b7ad8e66396e6f6be90d4d80324ef":[1,0,1,0,7],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a66f8cc4671e36e234337cc101a01631e":[1,0,1,0,3],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a8d9885cecfe6a314db18832f1be97aca":[1,0,1,0,4],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a973f865ac9b75042b31ec29d88f2b606":[1,0,1,0,2],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a9df8c71ce4b613af1cea6978fc007b1d":[1,0,1,0,6],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#aa74545ed45a18b2a807e4c4645ca770d":[1,0,1,0,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#ab37f949ba865b5fa7724e7c9c6d76a6f":[1,0,1,0,0],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#ac2c6ea02c7027d99f0252eade569b97d":[1,0,1,0,5],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#ae5d5052019f262dd2a9b66aa1e535cd3":[1,0,1,0,9],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html":[1,0,1,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html#a1f14a246334ddd6671263490f8e16844":[1,0,1,1,3],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html#aaffd7eb2871e03b6e0d3cc997b440661":[1,0,1,1,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html#ab7105c1bb1955af67381c789fdd6524e":[1,0,1,1,2],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html#af7753169ad5c7a29744dee3fc8a3adf8":[1,0,1,1,0],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html":[1,0,1,2],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a0230b832dbe37d2bfc73a230150dee22":[1,0,1,2,4],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a2ba3813b1ffc4880b9f5562c22cfdf02":[1,0,1,2,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a305aa4c64d8478f19d744f2d4a381742":[1,0,1,2,3],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a3f76738d15b4e1a86d2e0fbd2319a9f2":[1,0,1,2,7],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a5a85978f50c8df53807fb15364f9fede":[1,0,1,2,9],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a880033c1372f24b9f8dae6d0c8bf0f6a":[1,0,1,2,0],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a8e9dbdec86eb77a43911699e59307865":[1,0,1,2,2],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a972127506388c3595adb9cb2da717acf":[1,0,1,2,6],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#acdf0390f0d202c543fe2fd4262912cc0":[1,0,1,2,8],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#ad8e51c59e1c4c49114736a982410b130":[1,0,1,2,5],
"examples.html":[6],
"group__PkgShapeRegularizationRef.html":[1,0],
"group__PkgShapeRegularizationRefConcepts.html":[1,0,0],
"group__PkgShapeRegularizationRefContours.html":[1,0,2],
"group__PkgShapeRegularizationRefContours.html#ga2dda0da8c03e78e2dc1dd1355c85892c":[1,0,2,6],
"group__PkgShapeRegularizationRefContours.html#ga7e2f3e7e76c52a3acef42a0d413a17c6":[1,0,2,3],
"group__PkgShapeRegularizationRefContours.html#gab7cdbc7adcfeb23d7e01152ac63b9c74":[1,0,2,4],
"group__PkgShapeRegularizationRefContours.html#gae860b28fa0fde23f6f6540f483b4ecff":[1,0,2,5],
"group__PkgShapeRegularizationRefPlanes.html":[1,0,3],
"group__PkgShapeRegularizationRefPlanes.html#ga9ace5aafd056ce9ccb348c96e38d361a":[1,0,3,0],
"group__PkgShapeRegularizationRefSegments.html":[1,0,1],
"group__PkgShapeRegularizationRefSegments.html#ga0d6acc6431d79b38a7938c821e00a0c3":[1,0,1,6],
"group__PkgShapeRegularizationRefSegments.html#ga3cde2421ff91530c13c9e8f1feaeae1c":[1,0,1,8],
"group__PkgShapeRegularizationRefSegments.html#ga4b3211181f059dc7985aa50f7dfe63c8":[1,0,1,7],
"group__PkgShapeRegularizationRefSegments.html#ga7ade7f4682f9953fcf36669b2079f4d9":[1,0,1,3],
"group__PkgShapeRegularizationRefSegments.html#ga7fe1c4b39b16dee49ba9c41dc3c0b0f8":[1,0,1,4],
"group__PkgShapeRegularizationRefSegments.html#ga9312b7fea9ddc4beae7b166ccc4607df":[1,0,1,9],
"group__PkgShapeRegularizationRefSegments.html#gac72eca9b32b73a3713edffd2da5609f2":[1,0,1,5],
"hasModels.html":[3],
"index.html":[],
"index.html":[0],
"index.html#Contour_Regularization":[0,2],
"index.html#Contour_Regularization_Closed":[0,2,0],
"index.html#Contour_Regularization_Open":[0,2,1],
"index.html#Contour_Regularization_Performance":[0,2,2],
"index.html#Plane_Regularization":[0,3],
"index.html#QP_Regularization":[0,4],
"index.html#QP_Regularization_Framework":[0,4,0],
"index.html#QP_Regularization_Implementation":[0,4,4],
"index.html#QP_Regularization_Neighborhood":[0,4,1],
"index.html#QP_Regularization_Segments":[0,1],
"index.html#QP_Regularization_Segments_Angles":[0,1,1],
"index.html#QP_Regularization_Segments_Delaunay":[0,1,0],
"index.html#QP_Regularization_Segments_Examples":[0,1,3],
"index.html#QP_Regularization_Segments_Groups":[0,1,4,0],
"index.html#QP_Regularization_Segments_Offset":[0,1,2],
"index.html#QP_Regularization_Segments_Performance":[0,1,5],
"index.html#QP_Regularization_Segments_Simplification":[0,1,4,1],
"index.html#QP_Regularization_Segments_Utils":[0,1,4],
"index.html#QP_Regularization_Solvers":[0,4,3],
"index.html#QP_Regularization_Type":[0,4,2],
"index.html#Shape_Regularization_Acknowledgements":[0,6],
"index.html#Shape_Regularization_History":[0,5],
"index.html#Shape_Regularization_Intro":[0,0],
"models.html":[2],
"modules.html":[1],
"pages.html":[]
};

==> CGAL-6.1-doc_html.tar.xz: doc_html/Shape_regularization/navtreeindex0.js <==
var NAVTREEINDEX0 =
{
"Shape__regularization_8h.html":[1,0,4],
"Shape_regularization_2regularize_100_segments_angles_8cpp-example.html":[4,2],
"Shape_regularization_2regularize_100_segments_offsets_8cpp-example.html":[4,3],
"Shape_regularization_2regularize_15_segments_8cpp-example.html":[4,1],
"Shape_regularization_2regularize_closed_contour_8cpp-example.html":[4,7],
"Shape_regularization_2regularize_contour_8cpp-example.html":[4,6],
"Shape_regularization_2regularize_framework_8cpp-example.html":[4,5],
"Shape_regularization_2regularize_open_contour_8cpp-example.html":[4,8],
"Shape_regularization_2regularize_planes_8cpp-example.html":[4,9],
"Shape_regularization_2regularize_real_data_2_8cpp-example.html":[4,4],
"Shape_regularization_2regularize_simple_8cpp-example.html":[4,0],
"annotated.html":[3],
"citelist.html":[2],
"classCGAL_1_1Shape__regularization_1_1ContourDirections.html":[1,0,0,0],
"classCGAL_1_1Shape__regularization_1_1ContourDirections.html#a07f23b0d134d1dfb32158f485aab15b8":[1,0,0,0,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Longest__direction__2.html":[1,0,2,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Longest__direction__2.html#a0fc2c281b36b3f9c5824538734c485ff":[1,0,2,0,1],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Longest__direction__2.html#a3d35a4bb19800df5b7e46b6a5923b1f6":[1,0,2,0,2],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Longest__direction__2.html#ac341399a7d4ddc8941fa27fcc95cd130":[1,0,2,0,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Multiple__directions__2.html":[1,0,2,1],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Multiple__directions__2.html#a3bffe403cb918489cdde4362abbe0b2f":[1,0,2,1,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Multiple__directions__2.html#a8bc93ecb54966ddf4b5308f51e2b4f81":[1,0,2,1,1],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1Multiple__directions__2.html#ab1775ab7c531dce022b9fa86dc95cde4":[1,0,2,1,2],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1User__defined__directions__2.html":[1,0,2,2],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1User__defined__directions__2.html#aa02be5c6aadc4a0c0699b3d8251bc0fc":[1,0,2,2,0],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1User__defined__directions__2.html#ac1ca61aba4d1ff79f9ef08e9fdac6425":[1,0,2,2,1],
"classCGAL_1_1Shape__regularization_1_1Contours_1_1User__defined__directions__2.html#afe401731658a57d04a96397cbb7a8118":[1,0,2,2,2],
"classCGAL_1_1Shape__regularization_1_1NeighborQuery.html":[1,0,0,1],
"classCGAL_1_1Shape__regularization_1_1NeighborQuery.html#afe9ac86f81427f217a72ee74523e4ade":[1,0,0,1,0],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html":[1,0,8],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html#a14be6914a0f2c588e2dbb8d6aed68260":[1,0,8,2],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html#a90b302fd0cbbd391a432e1182bc9b362":[1,0,8,3],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html#ac0e7fc3b4fc8deb95693c64ce3b57e12":[1,0,8,1],
"classCGAL_1_1Shape__regularization_1_1QP__regularization.html#af40e65f2d3843f342d0beb237904bb21":[1,0,8,0],
"classCGAL_1_1Shape__regularization_1_1RegularizationType.html":[1,0,0,2],
"classCGAL_1_1Shape__regularization_1_1RegularizationType.html#a5fa1b89221a8d2515acff817ceeb6946":[1,0,0,2,2],
"classCGAL_1_1Shape__regularization_1_1RegularizationType.html#a6425688d6368960b0aa5bfd0e6e13541":[1,0,0,2,0],
"classCGAL_1_1Shape__regularization_1_1RegularizationType.html#ac5bd68e930f080c0b619b3541c5fad9c":[1,0,0,2,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html":[1,0,1,0],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a024a82b6ec049e436213c2d398a9f90c":[1,0,1,0,8],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a1e7b7ad8e66396e6f6be90d4d80324ef":[1,0,1,0,7],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a66f8cc4671e36e234337cc101a01631e":[1,0,1,0,3],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a8d9885cecfe6a314db18832f1be97aca":[1,0,1,0,4],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a973f865ac9b75042b31ec29d88f2b606":[1,0,1,0,2],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#a9df8c71ce4b613af1cea6978fc007b1d":[1,0,1,0,6],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#aa74545ed45a18b2a807e4c4645ca770d":[1,0,1,0,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#ab37f949ba865b5fa7724e7c9c6d76a6f":[1,0,1,0,0],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#ac2c6ea02c7027d99f0252eade569b97d":[1,0,1,0,5],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Angle__regularization__2.html#ae5d5052019f262dd2a9b66aa1e535cd3":[1,0,1,0,9],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html":[1,0,1,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html#a1f14a246334ddd6671263490f8e16844":[1,0,1,1,3],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html#aaffd7eb2871e03b6e0d3cc997b440661":[1,0,1,1,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html#ab7105c1bb1955af67381c789fdd6524e":[1,0,1,1,2],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Delaunay__neighbor__query__2.html#af7753169ad5c7a29744dee3fc8a3adf8":[1,0,1,1,0],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html":[1,0,1,2],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a0230b832dbe37d2bfc73a230150dee22":[1,0,1,2,4],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a2ba3813b1ffc4880b9f5562c22cfdf02":[1,0,1,2,1],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a305aa4c64d8478f19d744f2d4a381742":[1,0,1,2,3],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a3f76738d15b4e1a86d2e0fbd2319a9f2":[1,0,1,2,7],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a5a85978f50c8df53807fb15364f9fede":[1,0,1,2,9],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a880033c1372f24b9f8dae6d0c8bf0f6a":[1,0,1,2,0],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a8e9dbdec86eb77a43911699e59307865":[1,0,1,2,2],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#a972127506388c3595adb9cb2da717acf":[1,0,1,2,6],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#acdf0390f0d202c543fe2fd4262912cc0":[1,0,1,2,8],
"classCGAL_1_1Shape__regularization_1_1Segments_1_1Offset__regularization__2.html#ad8e51c59e1c4c49114736a982410b130":[1,0,1,2,5],
"examples.html":[4],
"group__PkgShapeRegularizationRef.html":[1,0],
"group__PkgShapeRegularizationRefConcepts.html":[1,0,0],
"group__PkgShapeRegularizationRefContours.html":[1,0,2],
"group__PkgShapeRegularizationRefContours.html#ga2dda0da8c03e78e2dc1dd1355c85892c":[1,0,2,6],
"group__PkgShapeRegularizationRefContours.html#ga7e2f3e7e76c52a3acef42a0d413a17c6":[1,0,2,3],
"group__PkgShapeRegularizationRefContours.html#gab7cdbc7adcfeb23d7e01152ac63b9c74":[1,0,2,4],
"group__PkgShapeRegularizationRefContours.html#gae860b28fa0fde23f6f6540f483b4ecff":[1,0,2,5],
"group__PkgShapeRegularizationRefPlanes.html":[1,0,3],
"group__PkgShapeRegularizationRefPlanes.html#ga9ace5aafd056ce9ccb348c96e38d361a":[1,0,3,0],
"group__PkgShapeRegularizationRefSegments.html":[1,0,1],
"group__PkgShapeRegularizationRefSegments.html#ga0d6acc6431d79b38a7938c821e00a0c3":[1,0,1,6],
"group__PkgShapeRegularizationRefSegments.html#ga3cde2421ff91530c13c9e8f1feaeae1c":[1,0,1,8],
"group__PkgShapeRegularizationRefSegments.html#ga4b3211181f059dc7985aa50f7dfe63c8":[1,0,1,7],
"group__PkgShapeRegularizationRefSegments.html#ga7ade7f4682f9953fcf36669b2079f4d9":[1,0,1,3],
"group__PkgShapeRegularizationRefSegments.html#ga7fe1c4b39b16dee49ba9c41dc3c0b0f8":[1,0,1,4],
"group__PkgShapeRegularizationRefSegments.html#ga9312b7fea9ddc4beae7b166ccc4607df":[1,0,1,9],
"group__PkgShapeRegularizationRefSegments.html#gac72eca9b32b73a3713edffd2da5609f2":[1,0,1,5],
"index.html":[0],
"index.html":[],
"index.html#Contour_Regularization":[0,2],
"index.html#Contour_Regularization_Closed":[0,2,0],
"index.html#Contour_Regularization_Open":[0,2,1],
"index.html#Contour_Regularization_Performance":[0,2,2],
"index.html#Plane_Regularization":[0,3],
"index.html#QP_Regularization":[0,4],
"index.html#QP_Regularization_Framework":[0,4,0],
"index.html#QP_Regularization_Implementation":[0,4,4],
"index.html#QP_Regularization_Neighborhood":[0,4,1],
"index.html#QP_Regularization_Segments":[0,1],
"index.html#QP_Regularization_Segments_Angles":[0,1,1],
"index.html#QP_Regularization_Segments_Delaunay":[0,1,0],
"index.html#QP_Regularization_Segments_Examples":[0,1,3],
"index.html#QP_Regularization_Segments_Groups":[0,1,4,0],
"index.html#QP_Regularization_Segments_Offset":[0,1,2],
"index.html#QP_Regularization_Segments_Performance":[0,1,5],
"index.html#QP_Regularization_Segments_Simplification":[0,1,4,1],
"index.html#QP_Regularization_Segments_Utils":[0,1,4],
"index.html#QP_Regularization_Solvers":[0,4,3],
"index.html#QP_Regularization_Type":[0,4,2],
"index.html#Shape_Regularization_Acknowledgements":[0,6],
"index.html#Shape_Regularization_History":[0,5],
"index.html#Shape_Regularization_Intro":[0,0],
"modules.html":[1],
"pages.html":[],
"regularize__contours_8h.html":[1,0,5],
"regularize__planes_8h.html":[1,0,6],
"regularize__segments_8h.html":[1,0,7]
};
